package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(0``````````0```````
M`*%@``````!``#@`"`!``!8`%0````8````$`````````$``````````0```
M``````!``````````<`````````!P``````````(`````P````0````````"
M``````````(``````````@``````````&``````````8``````````$````!
M````!0```````````````````````````````````````)?0````````E]``
M```````0``````$````&````````F\````````"KP````````*O`````````
M!+@````````%$````````!```````@````8```````";T````````*O0````
M````J]`````````!X`````````'@``````````AD=.50````!````````)',
M````````D<P```````"1S`````````#4`````````-0`````````!&1TY5$`
M```&````````````````````````````````````````````````````````
M```````09'3E4@````0```````";P````````*O`````````J\`````````$
M0`````````1```````````$O;&EB+VQD+6UU<VPM<S,Y,'@N<V\N,0`````1
M````10````0````(@`1`!0`0$""$`(:`!!``*`D$``D``"&""`($ND$8@(@`
M````````10```$D```!-````3@```%0```!5````5@````````!8````60``
M``````!:````6P```%T``````````'R:?VH.[]/J+4?>SA_?Q6^VF\4N#O&-
MN'S49-0.Y/\A'%AQV6!LH?HL/^7";XL!LH?7^D(!QD?B?)+CN](\PU5FS*]G
MTW`'B.S514/MVV(SS"6,%9N<J7\*`J?@4)X::TG[X*,`````````````````
M`````````````````````P``!P```````!?````````````````!$@``````
M```````````````````````)$0````````````````````````````&U$0``
M``````````````````````````$^$@`````````````````````````````0
M$@````````````````````````````&.$@``````````````````````````
M```8$@`````````````````````````````?$@``````````````````````
M``````'"$@````````````````````````````&:$@``````````````````
M```````````H(`````````````````````````````+$(0``````````````
M``````````````!`$@````````````````````````````!&$@``````````
M``````````````````)U$@````````````````````````````*T$@``````
M``````````````````````'=$@````````````````````````````!-$@``
M``````````````````````````)C$@````````````````````````````!4
M$@````````````````````````````!<$@``````````````````````````
M``)]$@````````````````````````````!D$@``````````````````````
M``````),$@````````````````````````````!L$@``````````````````
M``````````!R$@````````````````````````````![(```````````````
M``````````````*M$@````````````````````````````"7$@``````````
M``````````````````"<$@````````````````````````````%;%@``````
M``````````````````````)J$@````````````````````````````(*$@``
M``````````````````````````"C$@````````````````````````````'\
M$@````````````````````````````,($@``````````````````````````
M``+#$0````````````````````````````(N$@``````````````````````
M``````*3$@````````````````````````````+%$0``````````````````
M``````````"J$@````````````````````````````%,$@``````````````
M``````````````"S(@````````````````````````````#"(```````````
M``````````````````#8$@````````````````````````````*$$@``````
M``````````````````````(:$@````````````````````````````#=$@``
M``````````````````````````#C(`````````````````````````````)7
M$@````````````````````````````#]$@``````````````````````````
M``%_$@````````````````````````````$"$@``````````````````````
M``````(\$@````````````````````````````%N$@``````````````````
M``````````$($@````````````````````````````$9$@``````````````
M``````````````'8$@````````````````````````````!M$@``````````
M``````````````````'I$@````````````````````````````(C$@``````
M``````````````````````*,$@````````````````````````````*E$@``
M``````````````````````````$?$@````````````````````````````'3
M$@````````````````````````````$F$@``````````````````````````
M``$W$@````````````````````````````*@$@``"0```````!\`````````
M`?H```&O$@``"@```````%#@``````````(```-*$@``"0```````"^X````
M````!D````/V$@``"0```````#@X`````````&@```,G$@``"0```````"G`
M``````````8```.T$@``!P```````!?```````````(```-M$@``"0``````
M`#7X`````````CP```/:$@``"0```````"G(`````````@(```.E$```$P``
M`````+!X``````````````,X$@``"0```````"\(`````````*P```-7$@``
M"0```````"@@`````````#@```-?$@``"0```````"YH`````````&P```.#
M$@``"0```````$Y@`````````6@```.8$@``"0```````"O0`````````#0`
M``/Q$```$P```````+#0``````````````+M$@``"0```````"$P````````
M`#P```.Z$@``"0```````"P(`````````2H```..$0``$@```````+!P````
M``````@```/3$```$@```````+!X``````````````.J$@``"0```````"$`
M``````````````.Q$@``"0```````$WP`````````&P```+V$@``"0``````
M`"[8`````````"P```,1$@``"0```````"C``````````/X```/G$@``"0``
M`````$_(`````````18```/&$@``"0```````"TX`````````2X`;W!E;F1I
M<@!S=&1E<G(`<F5A;&QO8P!A8V-E<W,`<VYP<FEN=&8`7U]D97)E9VES=&5R
M7V9R86UE7VEN9F\`;'-E96L`9V5T<&ED`'5N;&EN:P!M96UM;W9E`'-T<FYC
M;7``<W1R<F-H<@!L<W1A=`!C;&]S961I<@!?251-7V1E<F5G:7-T97)434-L
M;VYE5&%B;&4`;W!E;@!S=')S='(`<W1R8VAR`')E861L:6YK`%]?8WAA7V9I
M;F%L:7IE`%]?<F5G:7-T97)?9G)A;65?:6YF;P!E>&ET`&-L;W-E`%])5$U?
M<F5G:7-T97)434-L;VYE5&%B;&4`<F5A9`!R;61I<@!?7V5R<FYO7VQO8V%T
M:6]N`&UK9&ER`&UE;6-P>0!?7W-T86-K7V-H:U]F86EL`&=E='5I9`!097)L
M7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!,7V-U<G)E;G1?8V]N=&5X=`!0
M97)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E
M<FQ?8W)O86M?;F]C;VYT97AT`%]F:6YI`%!,7V1O7W5N9'5M<`!097)L7VYE
M=UA37V9L86=S`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U
M;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`
M4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E<@!P97)L
M7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`')E861D:7(`
M<W1R8W!Y`&9P<FEN=&8`<W1R=&]K`%]?;&EB8U]S=&%R=%]M86EN`'-P<FEN
M=&8`<W1R9'5P`'!T:')E861?871F;W)K`%]?96YV:7)O;@!L:6)P97)L+G-O
M`&QI8F,N;75S;"US,SDP>"YS;RXQ`%]S=&%R=%]C`&=E=%]U<V5R;F%M95]F
M<F]M7V=E='!W=6ED`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?8W5R<F5N
M=%]E>&5C`'!A<E]S971U<%]L:6)P871H`'!A<E]M:W1M<&1I<@!X<U]I;FET
M`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]"3T]4`'-H85]U<&1A
M=&4`;7E?<&%R7W!L`'!A<E]B87-E;F%M90!?7V)S<U]S=&%R=`!S:&%?:6YI
M=`!P87)?9&ER;F%M90!P87)?:6YI=%]E;G8`7V5D871A`'!A<E]F:6YD<')O
M9P!S:&%?9FEN86P`7V5N9`!P87)?8VQE86YU<``O=7-R+VQI8B]P97)L-2]C
M;W)E7W!E<FPO0T]210````````"KP``````````,````````(D@```````"K
MR``````````,````````(>````````"OB``````````,````````'P``````
M``"OH``````````,````````4.````````"ON``````````,````````%\``
M``````"P```````````,````````L`````````"P$``````````,````````
M4\8```````"P&``````````,````````4/P```````"P*``````````,````
M````4>@```````"P,``````````,````````4>P```````"P.``````````,
M````````4[H```````"P0``````````,````````44X```````"P2```````
M```,````````4\(```````"P6``````````,````````4ZH```````"P8```
M```````,````````4[````````"P<``````````,````````4\P```````"O
MD`````,````*``````````````````"OF`````0````*````````````````
M``"OJ`````P````*``````````````````"OL````!P````*````````````
M``````"OP````"`````X``````````````````"OR````"D````*````````
M``````````"OT````"P````*``````````````````"OV````"T````*````
M``````````````"OX````#(````*``````````````````"OZ````#<````*
M``````````````````"O\````#@````*``````````````````"O^````#T`
M```*``````````````````"MR`````(````+``````````````````"MT```
M``4````+``````````````````"MV`````8````+``````````````````"M
MX`````<````+``````````````````"MZ`````@````+````````````````
M``"M\`````D````+``````````````````"M^`````H````+````````````
M``````"N``````L````+``````````````````"N"`````P````+````````
M``````````"N$`````X````+``````````````````"N&`````\````+````
M``````````````"N(````!`````+``````````````````"N*````!$````+
M``````````````````"N,````!(````+``````````````````"N.````!,`
M```+``````````````````"N0````!0````+``````````````````"N2```
M`!4````+``````````````````"N4````!8````+``````````````````"N
M6````!<````+``````````````````"N8````!@````+````````````````
M``"N:````!D````+``````````````````"N<````!H````+````````````
M``````"N>````!L````+``````````````````"N@````!T````+````````
M``````````"NB````!X````+``````````````````"ND````!\````+````
M``````````````"NF````"$````+``````````````````"NH````"(````+
M``````````````````"NJ````",````+``````````````````"NL````"0`
M```+``````````````````"NN````"4````+``````````````````"NP```
M`"<````+``````````````````"NR````"@````+``````````````````"N
MT````"H````+``````````````````"NV````"L````+````````````````
M``"NX````"P````+``````````````````"NZ````"T````+````````````
M``````"N\````"X````+``````````````````"N^````"\````+````````
M``````````"O`````#`````+``````````````````"O"````#$````+````
M``````````````"O$````#,````+``````````````````"O&````#0````+
M``````````````````"O(````#4````+``````````````````"O*````#8`
M```+``````````````````"O,````#D````+``````````````````"O.```
M`#H````+``````````````````"O0````#L````+``````````````````"O
M2````#P````+``````````````````"O4````#X````+````````````````
M``"O6````#\````+``````````````````"O8````$`````+````````````
M``````"O:````$$````+``````````````````"O<````$(````+````````
M``````````"O>````$,````+``````````````````"O@````$0````+````
M``````#K[_!P`"2Y!``/I_O_8.,`\```).OO\1``!`?^XQ#P.``DP!```$KG
MT@?P,!`(XQ`0$``$!_$'``<`!P#`$```2N;C$!````0'\0T0XQ`0#``4P/3_
M___E`````,`0``!*VN,0$```!`?Q#1#C$!`,`!3`]/___]4````8P!```$K.
MXQ`0```$!_$-$.,0$`P`%,#T____Q0```##`$```2L+C$!````0'\0T0XQ`0
M#``4P/3___^U````2,`0``!*MN,0$```!`?Q#1#C$!`,`!3`]/___Z4```!@
MP!```$JJXQ`0```$!_$-$.,0$`P`%,#T____E0```'C`$```2I[C$!````0'
M\0T0XQ`0#``4P/3___^%````D,`0``!*DN,0$```!`?Q#1#C$!`,`!3`]/__
M_W4```"HP!```$J&XQ`0```$!_$-$.,0$`P`%,#T____90```,#`$```2GKC
M$!````0'\0T0XQ`0#``4P/3___]5````V,`0``!*;N,0$```!`?Q#1#C$!`,
M`!3`]/___T4```#PP!```$IBXQ`0```$!_$-$.,0$`P`%,#T____-0```0C`
M$```2E;C$!````0'\0T0XQ`0#``4P/3___\E```!(,`0``!*2N,0$```!`?Q
M#1#C$!`,`!3`]/___Q4```$XP!```$H^XQ`0```$!_$-$.,0$`P`%,#T____
M!0```5#`$```2C+C$!````0'\0T0XQ`0#``4P/3___[U```!:,`0``!*)N,0
M$```!`?Q#1#C$!`,`!3`]/___N4```&`P!```$H:XQ`0```$!_$-$.,0$`P`
M%,#T___^U0```9C`$```2@[C$!````0'\0T0XQ`0#``4P/3___[%```!L,`0
M``!*`N,0$```!`?Q#1#C$!`,`!3`]/___K4```'(P!```$GVXQ`0```$!_$-
M$.,0$`P`%,#T___^I0```>#`$```2>KC$!````0'\0T0XQ`0#``4P/3___Z5
M```!^,`0``!)WN,0$```!`?Q#1#C$!`,`!3`]/___H4```(0P!```$G2XQ`0
M```$!_$-$.,0$`P`%,#T___^=0```BC`$```2<;C$!````0'\0T0XQ`0#``4
MP/3___YE```"0,`0``!)NN,0$```!`?Q#1#C$!`,`!3`]/___E4```)8P!``
M`$FNXQ`0```$!_$-$.,0$`P`%,#T___^10```G#`$```2:+C$!````0'\0T0
MXQ`0#``4P/3___XU```"B,`0``!)EN,0$```!`?Q#1#C$!`,`!3`]/___B4`
M``*@P!```$F*XQ`0```$!_$-$.,0$`P`%,#T___^%0```KC`$```27[C$!``
M``0'\0T0XQ`0#``4P/3___X%```"T,`0``!)<N,0$```!`?Q#1#C$!`,`!3`
M]/___?4```+HP!```$EFXQ`0```$!_$-$.,0$`P`%,#T___]Y0```P#`$```
M25KC$!````0'\0T0XQ`0#``4P/3___W5```#&,`0``!)3N,0$```!`?Q#1#C
M$!`,`!3`]/___<4```,PP!```$E"XQ`0```$!_$-$.,0$`P`%,#T___]M0``
M`TC`$```23;C$!````0'\0T0XQ`0#``4P/3___VE```#8,`0``!)*N,0$```
M!`?Q#1#C$!`,`!3`]/___94```-XP!```$D>XQ`0```$!_$-$.,0$`P`%,#T
M___]A0```Y#`$```21+C$!````0'\0T0XQ`0#``4P/3___UU```#J,`0``!)
M!N,0$```!`?Q#1#C$!`,`!3`]/___64```/`P!```$CZXQ`0```$!_$-$.,0
M$`P`%,#T___]50```]C`$```2.[C$!````0'\0T0XQ`0#``4P/3___U%```#
M\,`0``!(XN,0$```!`?Q#1#C$!`,`!3`]/___34```0(P!```$C6XQ`0```$
M!_$-$.,0$`P`%,#T___])0``!"#`$```2,KC$!````0'\0T0XQ`0#``4P/3_
M__T5```$.,`0``!(ON,0$```!`?Q#1#C$!`,`!3`]/___04```10P!```$BR
MXQ`0```$!_$-$.,0$`P`%,#T___\]0``!&C`$```2*;C$!````0'\0T0XQ`0
M#``4P/3___SE```$@,`0``!(FN,0$```!`?Q#1#C$!`,`!3`]/___-4```28
MP!```$B.XQ`0```$!_$-$.,0$`P`%,#T___\Q0``!+#`$```2(+C$!````0'
M\0T0XQ`0#``4P/3___RU```$R,`0``!(=N,0$```!`?Q#1#C$!`,`!3`]/__
M_*4```3@P!```$AJXQ`0```$!_$-$.,0$`P`%,#T___\E0``!/C`$```2%[C
M$!````0'\0T0XQ`0#``4P/3___R%```%$,`0``!(4N,0$```!`?Q#1#C$!`,
M`!3`]/___'4```4H`````.MO\#``)./P_TC_<>,P\*@`).-`\*``)%`@\+1!
M0/"@03#PJ$$@\+2R3P"PP.7___Z(Q$@``$ACQ"@``$A<N00`-,#E___]'<08
M``!(*.N[`"``#94`$`"R3P"QIW0`'L#E___][L0K``!(L>PF``@`?*<I``'`
MY?___I/`Y?___O#`$```2!_C$!````3C$;````22`!HGP!```$@4XQ`0```$
MXQ&P```$6"#PM)8#%'KLL@`#`-BG*@`$N10`(NLB``,`#<#E___^J^-`\*@`
M!.,00```!.,0(```),`0```9XN,0(`@`),08``!(0^,0(!``),`0```9V.,0
M(!@`)+D$`%+$*P``2%FG&``!XR#PM``2N?+0(:<Y``#L$P`$`-BG.P`!N10`
M$>L1``,`#;D(`!6G)@!7N10`2^5($````*=I``#`,```!`C$*```2#W`Y?__
M_108LNPF``H`?L0H``!(,\#E___^.ABRQ"@``$@LP.7___VSP"```!B/P.4`
M``%;["8`'P!\P!```$@9XQ`0```"IW0`"\`@```85L#E```!2L0K``!("\`0
M``!(".,@$````J>$``7`Y0``"[S$*```2`'`Y?___NC`Y?__^Z6Y%``KZV_P
MZ``$!_[KHP`#``WC"D````3C`!```"2G]/^4!P<'!P<'N00`+\`P````$N,P
M,```&*?[_V"G"0``XP#P```DP/0````)!P<'!P``BJ@'!P<'ZV_P,``D04`@
M"./P_UC_<<1H``!',.5(\*```,18``!'-N,P(`0`%,0H``!'&,#E___]3^MO
M\-@`!`?^!P<'!\`0``!'A,`@``!'@>P2``J`9,08``!'%^P8``0`?`?Q!_X'
M!P<'!P?`(```1W#`$```1VVY"0`2ZR$``P`*ZS$`/P`,N0@`,NLS``$`"NPX
M``T`?,08``!'#NP8``<`?,`@``!'5`?Q!_X'!P<'!P?KO_!8`"3`L```1TGC
M\/]@_W&5`+``IW0`(\`0``!&Z^,0$````J>$``C$*```1OO`Y?___2;`Y?__
M_ZW`$```1L;C$!````*GA``(P"```#@ZP.7___MED@&P`.N_\/@`!`?^!P<'
M!\`0``!&R.,0$````J>$`!?K[_!P`"3`,```1Q'C\/]@_W'`(```.!O`Y?__
M_0;K[_$0``3`]/___X[`]/___XOK;_`P`"3C\/]@_W'L*`!-`'S$&```1I?C
MH!````*GA`!$N00`8[D$`(*Y!`!"XQ!```"4[!8`+@!^&TBY!`!ZN10`E..P
M<````J>$`!VY!`!)N00`.+D$`"O`Y?__^YWL)@`?`'Y!&;``E3T0`*=T`!BY
MZ:"G0;FP`>NJ``,`"E"@8`"Y!``KZV_PT``$!_[L&/_5/7Y!0$`!I_3_RD%P
M<`BG]/_1I[D``*?T_^T'!^N_\%@`)./P_U#_<;)/`+!!,/"DZ[L`(``-LD\`
ML=('\*BP*,#E____EM4'\*BP**>$``7`Y?___:CKO_$(``0'_@<'!P<'!^N?
M\$@`)./P_U#_<;)/`*#KJ@`@``VR3P"AN00`LM('\*B@*$&0\*2Y!``YN00`
M*\#E____;.PF``L`?-4'\*B@**>$`![`Y?___7OC$/"D`!3$*```1?OK$0`#
M``WC$"````CC(!`(``3C(!```"3L*/_<`'Q!$!`(I_3_]>N?\/@`!`?^!P?K
MK_!0`"3C\/[(_W&R3P"PN00`HNN[`"``#4$P\*"R3P"QT@?Q,+`HP.7___LV
M["8`*0!^&!*G.$``6"#PN,`K``#P`.PC``B`=J4_H`#L(P`/8':G.0`"N00`
M*L#E___Z#!`2IQK__X@0`!_5!_$PL"BY%``AIX0`"<#E___]':<8``"G]/_T
MZZ_QB``$!_[K?_`X`"3C\/[(_W&R3P"`ZX@`(``-LD\`@=('\3"`*.PH`!$`
M?+D$`**5`"``IX0`"L#E___YF;D$`)+L)@!K`'S5!_$P@"BGA`""P.7___SL
M0;"P$\`0```6!Z<(``"Y!``KLET`$J<4__ZGA`!3P!```!7[N00`*[)=`!*G
M%/_^IX0`2+D$`#NY!``JIQD``+)>`!*G%/_^N0D`&J<I``"R7@`CIQ3__KD)
M`"L:(:<J``*Y%``BP.7___I&P#```!76N00`<KD$`%NY!`!*P.7___QZ03#P
MH+D$`"?`Y?___$/L*``M_WY8$/"XIRA``,`;``#P`.P2`"-@=KD$`"?`Y?__
M_W^Y!``GP.7___P<N00`*<#E___YU[D$`++L)O^9`'RY!``IP.7___I]N00`
M*L#E___[V*?T_X2Y!``GP.7___GQI_3_X.M_\7``!`?^!P<'!^MO\#``)./P
M_U#_<;)/`'#K=P`@``VR3P!QN00`HM('\*AP*+D$`+.5/3``IW0`!$&P,`&G
M"```N00`&Z>9``!!,/"DLEX`D:<4__ZY!``JN0D`F\#E___^(NPH`"8`?*<(
M``"G&0``N00`,K)>`!.G%/_^N0D`$NR1`&`@9:<9``#C,;```)!",2``IQL`
M`>PV__D`?-4'\*AP**>$`,3`Y?___!;$&```1)GC8!````2G&0``N00`@:<;
M``'K(0`#``WC(F_X_P*G=/_V["@``@#8P!```$3VN10`(N,0$```$NLB``,`
M#:>$`'FY!``RN00`)L#E___XJ\08``!$;N,@$```).PH_\<`?.P8``$`V,0H
M``!$8KD4`!'C("````3K$0`#``U0@/"D01$@`.5($````+D$`!KC(!```)3L
M*``&`'[L)@!J/7ZY"0`:["D``@#9N1@`(>.`\*0`%,1H``!$.^N(``,`#;D$
M`-CCT&````C`Y?__^3KC(-```"3L*/^)`'SC$&````3C&!````3C(*```)!"
M(!``0:"@`;D$`#'`*P```/]!$!`!IX0`!>PF__`]?I(],`"G*0``XS*P``"0
M0C(0`*<K``'L-O_Y`'RG]/]?P!```$1RY4P0```!P.7___D"N00`TNPH_U(`
M?+D4`$BY!``VZT0``P`-P.7___D#Q!@``$/FX]`0```DI_3_>T$0$`&G]/^.
MZV_PX``$!_X'!P<'P!```$/0LD\`(.,0$```!.LB`"``#<!0```TQK)/`"'$
M2```0]3`,```%&'C(2````3`]/__^N7K;_`P`"3`$```0['C\/]8_W'CL!``
M``2R3P"@ZZH`(``-LD\`H>,KH```!,!@```5CL#E____R[D$`%;E2/"@``#`
M0```!J_C*Z````3`,```%#_`Y?__^`CK;_#8``0'_@<'!P<'!^MO\#``)./P
M_U#]<>,0\*@"<;)/`'#K=P`@``VR3P!QT@<0`'`HP.7___@K0;#PIKD$`%+`
M8```%"/`0```%"*G.1`!N00`*\#E___WRNPF`!#_?J>Y``#C$/"H`G'5!Q``
M<"BGA`!'P.7___K*["`0`"!QXZ#PIP%QITD0`+D$`#JY!``KP.7___EKN00`
MDNPD_^(`?J<J``&Y%``BP.7___@_N00`LNPH_]8`?+D4`(GL*@`'H&6YZ(`2
MN6%`H>RZ``?`9;GH@!JY84"Q[)`0`2!RN00`2+D$`#JY!``KP.7___IN01BP
M`)(`$`"G]/^UN00`*^MO\.`"!`?^!P?`]/___X`'!^MO\#``)./P_L#^<>,0
M\3@!<;D$`+*Y!`"CLD\`@,`@```3LNN(`"``#;)/`('2!Q``@"C`Y?___)ZG
M.0`ON00`DKD$`"O`Y?__^+?L*``6`'RY!``[P"```!.;P.7___WFXQ#Q.`%Q
MU0<0`(`HIX0`Q,#E___Z0;D$`"K`<```$UQ!H/$XP.7___A'P#```!.'0=#P
MJ,#E___Y[[D$`%+L6/_9`'R5`%``N>*`5^R8``\`?*<(``"Y!``5N00`*;)=
M`!*G%/_^IX0`B[D$`"6G"```IQD``+)>`!*G%/_^XR`?__]QN>E0,>Q2``8@
M9>Q6``7_?*<Y``&G-P`XIP@``+D$`!6G*0``LEX`(:<4__ZY"0`EIQD``+D$
M`#NR7@`3IQ3__KD)`!M!$A`!IRD/_^P2_Y`@9>.P\*``),!@```3+\!````3
MF:<Y$`"Y!``JP.7___;!IQ@0`*<J``'L(0`0P'>G]``!E2\@`*=T_\B2`"``
MXR`O__]QI_3_O[D$`#VY!``JP.7___E6["8`*`!^6!#PP*4O@`#`&P``\`#L
M$@`>8':G.0`!N00`*L#E___V@NPF`!0`?KD$`#K`(```$N;`Y?___3&Y!``J
MP.7___>BN00`LJ?T_T3`,```$MZG*0``P.7___E&N00`4J?T_U>Y!``KZV_Q
M<`$$!_X'!P<'!P?KO_!8`"2G.0`OX_#_8/]QN00`LL#E___W/.PH``4`?$&P
M(`&Y!``KZ[_P^``$P/3___=O!P<'!^NO\%``)./P_UC^<;)/`*#C$/"@`7'K
MJ@`@``VR3P"AT@<0`*`H["@`"0!\N00`,I4`(`"G=``-XQ#PH`%QU0<0`*`H
MIX0`9L#E___Y-J<(``"G&0``LEX`$J<4__ZG*1``N0D`$Z<;``'L$@!<(&5!
ML/"@N00`*\#E___VWKD$`"NG"```IQD``+)>`!*G%/_^XR`?__]QN>FP,>RR
M``L@9>,0\*@!<:=)$`?L%``%8&2G.0`!IS<`(J<Y`"^Y!``KP.7___;)["C_
MN`!\["L`!<!ED@`@`+D$`"O`Y?__]OSC$/"@`7'5!Q``H"BG=/^MZZ_P^`$$
M!_Z5+R``IW3_WI(`(`#C("___W&G]/_5P"```!'RZZ_P^`$$P/3___;<IRD`
M`*?T_]X'!P<'!P?K[_!P`"3`(```$A3C\/]@_W'`Y?__^QO`(```$A#`Y?__
M^Q7`(```$@[`Y?__^P_`(```$@W`Y?__^PG`(```$@O`Y?__^P/`(```$@W`
MY?__^OW`(```$=_`Y?__^O?`(```$@?`Y?__^O'`(```$@;`Y?__^NO`(```
M$@7`Y?__^N7`(```$<S`Y?__^M_`(```$?[`Y?__^K7L*``+`'RY!``RP"``
M`!'IP.7___P&P"```!'VP.7___JDN00`,NPH``D`?,`@```1],#E___[]<`@
M```1],#E___ZD[D$`#+L*``5`'S`(```$93`Y?__^^3`,```$?3`(```$:OK
M[_$0``3`]/__^]C`(```$=_`Y?__^G:Y!``R["C_[`!\P"```!&EI_3_XP<'
MQ!T``$#0IQ[__Z=T`"WK[_!P`"3`(```$97C\/]@_W'`Y?__^ECL*``;`'R_
M$2``IX0`%L`7````,+F$`!&Y`P`1[!$_OP%5Q!\``$"LQ"P``$"IZ^_Q$``$
M!_ZG&```I_3_],0L``!`G@?^!P<'!^OO\'``)./P_V#_<<#E___W_,#E___V
M:>PH``8`?.,@(```!.OO\1``!`?^!P<'!^MO\#``)+D$`++C\/]@_W'`(```
M$8#`Y?__^@VY!``[["@`"0!\N00`8I4`(`"G=``+P"```!%OZV_PT``$P/3_
M__M5P.7___7H["8`+0!\IP@``+D$`!NR7@`AIQ3__KD$`#:G&0``LEX`$Z<4
M__ZY"0`6N0D`*T$B$`+`Y?__]2S`,```$5JY!`"BP%```!#GN00`2\#E___W
M7[D$`#JG]/_)ZV_PT``$!_X'!P<'ZV_P,``DX_#^&/=QXQ#QX`AQLD\`@.N(
M`"``#;)/`('2!Q``@"C`$```0!6Y!`"2P"```!"QT@_PL!`(T@?PP!`8TB_P
MX!`@T@_PR!!0T@?PV!!@P.7___F6["@`'P!\N00`LI4`(`"GA``8P.7___]R
MXQ#QX`AQU0<0`(`HIX0`!<#E___W0;D$`"OK;_(8"`3`]/__]4G`Y?___T2Y
M!`"R["8`)0!\0:#PR.,@H````J=T``?`L```$-VG]``8P.7___E@["8`!P!\
MIZL`"*?T_^Z5`"``IX3_^L#E___U)+D$`++L*/_S`'RG"```N00`&Z<I``"R
M7@`AIQ3__KD)`"OK(@`!``VG*P`!P.7___2+N00`8KD$`*+C0+```)3L1@";
M`'Y!H/#@X["@```"IX0`';D$`"O`Y?__^2.Y!`"R["@`F@!\E0`@`*>$`)7`
MY?__^7_L*`"0`'ZY!``KP.7___3AN00`LD&@\+#LM@`,`'SC<*````*GA`"5
ME0!P`*=T`'ZG"```N00`&Z=Y``"R7@!QIQ3__KD$`":G&0``LEX`$J<4__ZY
M"0`6N0D`>QIQIWH$!+D4`'>Y!``GP.7___0QXV#PH``DN00`HL`P```06<!@
M```04\!0```/Y[D$`$O`Y?__]EZG.0'`N00`*L#E___V!^PF`%G_?L#E___U
M\5A@(`#L:`!1$7[$&```/N.Y%`!FN00`6N-`D```!,`P```0-.,@$```!,#E
M___U::>Y``#C$/'@"''5!Q``@"BG=/\=N00`*^MO\A@(!`?^N00`*KD4`$3`
M,```$`S`Y?__]A]!L+`!0:"@`J?T_U2GJP`(I_3_6+D$`"=!H*`(P.7___CD
M["C_=`!^N00`)\#E___T1KD$`+*G]/]GI[D``*?T_V]!,/$0N00`*L#E___T
M%QC2["8`#0!^6!#Q**<H0`#`&P``\`#L$@`6@';$&```/H"Y!`!:XT"0```$
MP#````_QXR`0```$P.7___4(I_3_GUBP\2S`Y?__]A'LLO_H8'98$/$HIR@!
MP,`;```!_^P2_]Y@=KD$`"?`Y?__\W^Y!`"RP"````_WP.7___@EN00`,NPF
M`,8`?.-PD```!*<(``"G&0``N00`)[)>`!*G%/_^N0D`%^P<`#X#?KD4`"'C
M,G_\_W'`(```#]BR70`CIQ3__J=T`"_L&``-!'ZG&O_[N10`$4$1<`"5+Q``
MIW0`(N,0D`@``J>$`!VG"```IRD``+D$`#&R7@`CIQ3__KD)`"'L+``/`WWC
M,A_\_W'`(```#ZZR70`CIQ3__KGB@''`Y?___6CL)@#8`'ZY!``GISD``,#E
M___SJ+D$`)(8<NPH`,L`?J=)``*G.?_N06#QX,#E___RJ:=)``:Y!``VN00`
M*<#E___TL)4`\>"G=`!<E4/QX:=T`%B50?'BIW0`5)5#\>.G=`!0E4CQY*=T
M`$R51?'EIW0`2*=)``*G.?_&N00`*<#E___R?Z=)`"FY!``VN00`*<#E___T
MAL`0```/M>,0\*``),!0```.D;D$`$K`,```#TZY!``KP.7___4#N00`*L#E
M___TOKD$`#O`(```#G#`Y?__^,"Y!``KP.7___U'I_3^NN,@D```!,#E___Z
MG[D$`'+L)O\X`'RG]/\RITD``*<Y``"Y!``IP.7___(YP.4```R@N10`=[D$
M`-*E3X``N00`-KD$`"?`Y?__]#GL(@`T`'ZY!``G09#QHT%P\;?`Y?__]`VY
M!``]N00`*;D$`-?`Y0``#6JG:0`4XT"0``"0N00`)\`P```.E,#E___TIZ>;
M``&G>P`"IV?_\<`0```/0)(`\=_C$/"@`"2Y!`!MI_3_A[D4`$*Y!``VN00`
M+<#E```,CJ?T_[K`,```#F3`(```#BG`Y?__^$O`Y?__\>[`$```#QVY!`!B
MXQ#PH``DP%````WWN00`2L`P```.O+D$`"O`Y?__]&FG.0'`N00`*\#E___T
M$NPF_U__?L#E___S_%@0(`"G'@`1IW3_5<#E___QP\`0```.\N,0\*@`)*?:
M``&Y%``=N00`8N,0\*``),!0```-Q;D$`$K`,```#I&Y!``KP.7___0WI_3_
MSNN/\$``),`0```\X;)/`+#C$!````3KNP`@``VR3P"QXQ&P```$X_#_8/]Q
MP"````VST@`0L1"PP.7___:$["@`"P!\E3$@`*=T``:5`"`!IX0`!<#E___[
M=L`0```\MZ=9``/CD!````2G20`!P#````Y9XRFP```$P.7___)UN00`HNPH
M`"(`?.,0(!``!,!````.2>,P$```!.,IL```!,#E___R@>,0H!``!.,P$```
M!)%`,`VGA``(XRFP```$P.7___%QP!```#R`IUD``^.`$```!*=)``'`,```
M#B;C*+````3`Y?__\CZY!`"B["@`-P!\P"````TRP.7___8AN00`0NPH`!$`
M?.,0H!``!.,P$```!.,HL```!,#E___R0J?T`!W`Y?__^,_C$*`0``2Y!`"2
M["@`4P!\N00`0N,P$```!.,HL```!,#E___R*KD$`"G`Y?__\T7`$```/#2G
M20`!XZ`0```$P#````W=XYJP```$N00`*<#E___P<L!````-W;D$`#*Y!``I
MP.7___((XQJP```$D@`0L<`@```,U\#E___UR\0K```\C.PF`!T`?,0H```\
M@L#E___[_\0K```\@.PF`!$`?,`@```-N<#E___PA<0H```\<.-`(```!*?T
M_Y2G.0'`Q"@``#QJP.7___+EN00`4NP2``$`V.P<`!4!?^PH`!(1?L08```\
M5<1(```\5N,P$```!,`@```-H,#E___P6^N/\.``!`?^!P<'!^NO\%``)./P
M_V#_<;D$`++`Y?__^>#`Y?__^<&Y!`"BP.7___L(["@`'0!^[+@`&@!\E0"P
M`*>$`!7`,```#.*Y!``JP.7___%0[*(`"V!DN00`*^NO\/``!,#T___V`^NO
M\/``!`?^LD\`$.L1`"``#;)/`!'K;_`P`"2G60`(X_#\T/]QT@?S*!`HI[D`
M`$$0\*BY!``QXTL@.``$ZP0`(``,XP`P```DP$H`````XT`P"``DI[L`"*<[
M`!"G5__MITD`0.,P$&@`!.,P$$``@N,P$!``@N,P$```@NQ3(+\A5>Q3(#X!
M5N-0$(``)*<;``BG1__IXQ`@&``$XQ#PH``DXQ#PJ``$PAI:@GF9XQ`@(``(
MXS`@```$XT`@$``$XP`@"``$[+,@OR55[+,@.@56N0@`L>,0\*``!+GG$!2Y
M@``0XQ#PH`""XY#PL``$N0@`L<*:6H)YF>Q[(+\`5>.0\*``".R[.[\E5>L0
M``(`#.RW`#H%5NP0`"$>5N-0\,``!.S1(+\`5<):6H)YF;GGT*2Y@`"CN8(`
MI+D(`*FY"`"K[(H@OP!5[*H[OR55[*@`.@56Z[,``@`,XY#PN``$[+,`(1Y6
MPII:@GF9[&L@OP!5N8(`&[D(`)2Y@``7N8(`';D(`-6Y"``9XU#PR``$N0@`
M&L):6H)YF>NG``(`#.RG`"$>5KF"`+JY@`"XN8(`MKD(`+WLD2"_`%7L>B"_
M`%6Y"`!E[!$[OR55XU#PT``$[!D`.@56PEI:@GF9N0@`&^NX``(`#.RX`"$>
M5KF"`*NY@`"IN8(`I[D(`*;LT2"_`%7LBR"_`%6Y"`!U[!$[OR55XU#PV``$
M[!T`.@56PEI:@GF9N0@`&NNI``(`#.RI`"$>5KF"`+JY@`"]N8(`N+D(`+?L
M82"_`%7LFB"_`%6Y"`"%[!$[OR55XU#PX``$[!8`.@56PEI:@GF9N0@`&^N]
M``(`#.R]`"$>5KF"`*NY@`"FN8(`J;D(`*CL<2"_`%7LVR"_`%6Y"`"5[!$[
MOR55XU#PZ``$[!<`.@56PEI:@GF9N0@`&NNF``(`#.RF`"$>5KF"`+JY@`"W
MN8(`O;D(`+GL@2"_`%7L:B"_`%6Y"`#5[!$[OR55XU#P\``$[!@`.@56PEI:
M@GF9N0@`&^NW``(`#.RW`"$>5KF"`*NY@`"HN8(`IKD(`*WLD2"_`%7L>R"_
M`%6Y"`!E[!$[OR55XU#P^``$[!D`.@56PEI:@GF9N0@`&NNH``(`#.RH`"$>
M5KF"`+JY@`"YN8(`M[D(`+;LT2"_`%7LBB"_`%6Y"`!U[!$[OR55XU#Q```$
M[!T`.@56PEI:@GF9N0@`&^NY``(`#.RY`"$>5KF"`*NY@`"MN8(`J+D(`*?L
M82"_`%7LFR"_`%6Y"`"%[!$[OR55XU#Q"``$[!8`.@56PEI:@GF9N0@`&NNM
M``(`#.RM`"$>5KF"`+JY@`"VN8(`N;D(`+CL<2"_`%7LVB"_`%6Y"`"5[!$[
MOR55XU#Q$``$[!<`.@56PEI:@GF9N0@`&^NV``(`#.RV`"$>5KF"`*NY@`"G
MN8(`K;D(`*GL@2"_`%7L:R"_`%6Y"`#5[!$[OR55XU#Q&``$[!@`.@56PEI:
M@GF9N0@`&NNG``(`#.RG`"$>5KF"`+JY@`"XN8(`MKD(`+WLD2"_`%7L>B"_
M`%6Y"`!E[!$[OR55XU#Q(``$[!D`.@56PEI:@GF9N0@`&^NX``(`#.RX`"$>
M5KF"`*NY@`"IN8(`I[D(`*;LT2"_`%7LBR"_`%6Y"`!U[!$[OR55XU#Q*``$
M[!T`.@56PEI:@GF9N0@`&NNI``(`#.RI`"$>5KF"`+JY@`"]N8(`N+D(`+?L
M82"_`%7LFB"_`%6Y"`"%[!$[OR55XU#Q,``$[!8`.@56PEI:@GF9N0@`&^N]
M``(`#.R]`"$>5KF"`*NY@`"FN8(`J;D(`*CL<2"_`%7LVR"_`%6Y"`"5[!$[
MOR55XU#Q.``$[!<`.@56PEI:@GF9N0@`&NNF``(`#.RF`"$>5KF"`+JY@`"W
MN8(`O;D(`-6Y"`"Y[($@OP!5[&H@OP!5[!$[OR55[!@`.@56N0@`&^NW``(`
M#.RW`"$>5KF"`*NY@`"HN8(`IKD(`*WLT3N_)57LT2`Z!5;LD2"_`%6Y"`"M
M['L@OP!5Z]@``@`,[-@`(1Y6N>?0&^.P\4``!,*Z6H)YF;D(`+:Y@``9ZXD`
M`@`,N8(`%^R)`"$>5KD(`!NYYX"=[+H[OR55N8(`FNRZ(#H%5KD(`!OCL/%(
M``3"NF[9ZZ&Y"`"W['HBOSY5N1H`N>QZ`B$>5NR1.[\E5;GG<*CLD2`Z!5:Y
M@@"AN0@`N>QA(K\^5>.0\5``!.QA`B$>5L*:;MGKH;D:`)VY&@":[*L[OR55
M[*L@.@56N0@`FN.@\5@`!,*J;MGKH;GG8!>Y@@`;N1H`J+D:`*'L&3N_)57L
M&2`Z!5;LBR*_/E6Y"`"A[(L"(1Y6N>>`%KF"`!GCL/%@``3"NF[9ZZ&Y&@"W
M['DBOSY5N1H`L>QY`B$>5NP:.[\E5;GG<)CL&B`Z!5:Y@@":N0@`L>,0\6@`
M!,(:;MGKH;D:`!:Y&@`9[)L[OR55[)L@.@56N0@`&>R:(K\^5>R:`B$>5N.@
M\7``!,*J;MGKH;D:`*BYYY"'N8(`B[D:`*CL@3N_)57L@2`Z!5:Y"`"H[(LB
MOSY5[(L"(1Y6X[#Q>``$PKINV>NAN1H`M[GG@'FY@@!QN1H`M^QZ.[\E5>QZ
M(#H%5KD(`+?L<2*_/E7L<0(A'E;C$/&```3"&F[9ZZ&Y&@`9N>=PF+F"`)JY
M&@`9[)L[OR55[)L@.@56N0@`&>R:(K\^5>R:`B$>5N.@\8@`!,*J;MGKH;D:
M`*BYYY"'N8(`B[D:`*CL@3N_)57L@2`Z!5:Y"`"H[(LBOSY5[(L"(1Y6X[#Q
MD``$PKINV>NAN1H`M[GG@'FY@@!QN1H`M^QZ.[\E5>QZ(#H%5KD(`+?L<2*_
M/E7L<0(A'E;C$/&8``3"&F[9ZZ&Y&@`9N>=PF+F"`)JY&@`9[)L[OR55[)L@
M.@56N0@`&>R:(K\^5>R:`B$>5N.@\:``!,*J;MGKH;D:`*BYYY"'N8(`B[D:
M`*CL@3N_)57L@2`Z!5:Y"`"H[(LBOSY5[(L"(1Y6X[#QJ``$PKINV>NAN1H`
MM[GG@'FY@@!QN1H`M^QZ.[\E5>QZ(#H%5KD(`+?L<2*_/E7L<0(A'E;C$/&P
M``3"&F[9ZZ&Y&@`9N>=PF+F"`)JY&@`9[)L[OR55[)L@.@56N0@`&>R:(K\^
M5>R:`B$>5N.@\;@`!,*J;MGKH;D:`*BYYY"'N8(`B[D:`*CL@3N_)57L@2`Z
M!5:Y"`"H[(LBOSY5[(L"(1Y6X[#QP``$PKINV>NAN1H`M[GG@'FY@@!QN1H`
MM^QZ.[\E5>QZ(#H%5KD(`+?L<2*_/E7L<0(A'E;C$/'(``3"&F[9ZZ&Y&@`9
MN>=PF+F"`)JY&@`9[)L[OR55[)L@.@56[&HBOSY5N0@`&>QJ`B$>5KGG8)>Y
M@@";XZ#QT``$PJINV>NAN1H`J+D:`*GLD3N_)57LD2`Z!5:Y"`"I[)LBOSY5
M[)L"(1Y6N>>0MKF"`+'LBB"_`%7CT/'8``3"VF[9ZZ&Y&@#7N1H`V^RZ.[\E
M5>RX`#H%5KD(`-OLL2*_/E7LL0(A'E;C$/'@``3"&F[9ZZ&Y&@`6L\$``;GG
ML!FY@@`:L\T`H.Q](+\`5>S=.[\E5;D:`*'LUP`Z!5;K&``"``RY"`"M[!@`
M(1Y6[&H@OP!5[($@OP!5[*H[OR55N>2`6^RF`#H%5KGF$-NY@`#7N8$`U>-0
M\>@`!,):CQN\W+D:`%FY"`#5N0@`VNNG``(`#.RG`"$>5KGD@'JY@0`:N8``
M%KF!`!?C</'P``3">H\;O-RY&@![[)T@OP!5N>APL>S=.[\E5>L6``(`#.S9
M`#H%5NP6`"$>5KD(`+WL82"_`%7L>R"_`%6YY&!:[+L[OR55[+<`.@56N>80
MVKF``-FY@0#5XU#Q^``$PEJ/&[S<N0@`A;D(`-BY"`#;Z[D``@`,[+D`(1Y6
MN>1@F[F!`!NY@``7N8$`&>.0\@``!,*:CQN\W+D:`)KLC2"_`%6YZ)"A[-T[
MOR55ZQ<``@`,[-@`.@56[!<`(1Y6N0@`K>QQ(+\`5>R:(+\`5;GD<%OLJCN_
M)57LJ0`Z!5:YYA#;N8``V+F!`-7C4/((``3"6H\;O-RY"`!EN0@`UKD(`-KK
MJ``"``SLJ``A'E:YY'"*N8$`&KF``!FY@0`8XX#R$``$PHJ/&[S<N1H`B^QM
M(+\`5;GH@+'LW3N_)57LU@`Z!5:Y"`"][(L@OP!5ZQD``@`,[!D`(1Y6[+L[
MOR55[)$@OP!5[+@`.@56N>206KGF$-JY@`#6N8$`U>-0\A@`!,):CQN\W+D(
M`'6Y"`#7N0@`V^NV``(`#.RV`"$>5KGDD&NY@0`;N8``&+F!`!;C8/(@``3"
M:H\;O-RY&@!J['T@OP!5N>A@H>S=.[\E5>L8``(`#.S7`#H%5NP8`"$>5KD(
M`*WL@2"_`%7L:B"_`%6YY(!;[*H[OR55[*8`.@56N>80V[F``->Y@0#5XU#R
M*``$PEJ/&[S<N0@`E;D(`-FY"`#:ZZ<``@`,[*<`(1Y6N>2`>KF!`!JY@``6
MN8$`%^-P\C``!,)ZCQN\W+D:`'OLG2"_`%6YZ'"Q[-T[OR55ZQ8``@`,[-D`
M.@56[!8`(1Y6N0@`O>QA(+\`5>Q[(+\`5;GD8%KLNSN_)57LMP`Z!5:YYA#:
MN8``V;F!`-7C4/(X``3"6H\;O-RY"`"%N0@`V+D(`-OKN0`"``SLN0`A'E:Y
MY&";N8$`&[F``!>Y@0`9XY#R0``$PIJ/&[S<N1H`FNR-(+\`5;GHD*'LW3N_
M)57K%P`"``SLV``Z!5;L%P`A'E:Y"`"M['$@OP!5[)H@OP!5N>1P6^RJ.[\E
M5>RI`#H%5KGF$-NY@`#8N8$`U>-0\D@`!,):CQN\W+D(`&6Y"`#6N0@`VNNH
M``(`#.RH`"$>5KGD<(JY@0`:N8``&;F!`!CL;2"_`%7C@/)0``3LW3N_)57"
MBH\;O-SLU@`Z!5:Y&@"+N>B`L>L9``(`#.P9`"$>5NR1(+\`5;GDD%JY"`"]
MN>80VKF``-:Y@0#5XU#R6``$PEJ/&[S<N0@`=;D(`'WLBR"_`%7LNSN_)57L
MN``Z!5:Y"`"WZW8``@`,[-L@OP!5['8`(1Y6[+L[OR55N>209^R]`#H%5KF!
M`!>Y@``8N8$`%N-@\F``!,)JCQN\W+D:`&JY"``6N0@`&^NX``(`#.RX`"$>
M5NR+(+\`5;GD@%>YYK!GN8``;;F!`&7C4/)H``3"6H\;O-RY"`"5N0@`ENRA
M(+\`5>P1.[\E5>P:`#H%5KD(`!GKG0`"``SL82"_`%7LG0`A'E;L$3N_)56Y
MY(#9[!8`.@56N8$`N;F``+JY@0"]X]#R<``$PMJ/&[S<N1H`U[D(`+VY"`"Q
MZQH``@`,[!H`(1Y6[*$@OP!5N>2@6;GF$-FY@`#6N8$`U>-0\G@`!,):CQN\
MW+D(`(6Y"`"-['L@OP!5[-L[OR55[-L@.@56N>C0N.N&``(`#.R&`"$>5KGD
MH&BY@0`8N8``%[F!`!;C8/*```3":H\;O-RY&@!I[)L[OR55[)L@.@56N0@`
M%NMG``(`#+D(`!GL9P`A'E;CD/*(``2YYV!XPIK*8L'6N8(`>[D(`)KLH3N_
M)57LH2`Z!5:Y&@"7['LBOSY5N0@`FNQ[`B$>5KGG<*:Y@@"AX[#RD``$PKK*
M8L'6N1H`N.R!(K\^5;D:`+KL@0(A'E;LJ3N_)56YYX`7[*D@.@56N8(`&;D(
M`+KCH/*8``3"JLIBP=:Y&@"F[&DBOSY5N1H`H>QI`B$>5NP;.[\E5;GG8)CL
M&R`Z!5:Y@@";N0@`H>,0\J``!,(:RF+!UKD:`!>Y&@`9[)H[OR55[)H@.@56
MN0@`&>R;(K\^5>R;`B$>5N.P\J@`!,*ZRF+!UKD:`+BYYY"&N8(`BKD:`+CL
M@3N_)57L@2`Z!5:Y"`"X[(HBOSY5[(H"(1Y6N>>`>;F"`''CH/*P``3"JLIB
MP=:Y&@"FN1H`I^Q[.[\E5>Q[(#H%5KD(`*?L<2*_/E7L<0(A'E;C$/*X``3"
M&LIBP=:Y&@`9N>=PF+F"`)NY&@`9[)H[OR55[)H@.@56N0@`&>R;(K\^5>R;
M`B$>5N.P\L``!,*ZRF+!UKD:`+BYYY"'N8(`BKD:`+CL@3N_)57L@2`Z!5:Y
M"`"X[(HBOSY5[(H"(1Y6XZ#RR``$PJK*8L'6N1H`I[GG@'FY@@!QN1H`I^Q[
M.[\E5>Q[(#H%5KD(`*?L<2*_/E7L<0(A'E;C$/+0``3"&LIBP=:Y&@`9N>=P
MF+F"`)NY&@`9[)H[OR55[)H@.@56N0@`&>R;(K\^5>R;`B$>5N.P\M@`!,*Z
MRF+!UKD:`+BYYY"'N8(`BKD:`+CL@3N_)57L@2`Z!5:Y"`"X[(HBOSY5[(H"
M(1Y6XZ#RX``$PJK*8L'6N1H`I[GG@'FY@@!QN1H`I^Q[.[\E5>Q[(#H%5KD(
M`*?L<2*_/E7L<0(A'E;C$/+H``3"&LIBP=:Y&@`9N>=PF+F"`)NY&@`9[)H[
MOR55[)H@.@56N0@`&>R;(K\^5>R;`B$>5N.P\O``!,*ZRF+!UKD:`+BYYY"'
MN8(`BKD:`+CL@3N_)57L@2`Z!5:Y"`"X[(HBOSY5[(H"(1Y6XZ#R^``$PJK*
M8L'6N1H`I[GG@'FY@@!QN1H`I^Q[.[\E5>Q[(#H%5KD(`*?L<2*_/E7L<0(A
M'E;C$/,```3"&LIBP=:Y&@`9N>=PF+F"`)NY&@`9[)H[OR55[)H@.@56N0@`
M&>R;(K\^5>R;`B$>5N.P\P@`!,*ZRF+!UKD:`+BYYY"'N8(`BKD:`+CL@3N_
M)57L@2`Z!5:Y"`"X[(HBOSY5[(H"(1Y6XZ#S$``$N>>`:<*JRF+!UKF"`&&Y
M&@"GN1H`IKD$`'KLJSN_)57LJR`Z!5:Y"`!Z[*$BOSY5[*$"(1Y6XQ#S&``$
MPAK*8L'6N1H`&;GGH)BY@@";[&<@OP!5N1H`&>R7.[\E5>R6`#H%5KD(`!GL
MFR*_/E7LFP(A'E;CL/,@``3"NLIBP=;LT2"_`%6Y"``[[!$[OR55N>>0NNP=
M`#H%5KD:`#BY@@"WN1H`.[D(`!/`&@````#C$"```"3CH"`@``BY"`#0XY#P
MH``(P-H`````X]`@"``DP)H`````XY`@&``DP*H`````XZ`@(``DZQ8``@`,
M[!8`(1Y6N0@`%,`:`````.,0(!``)+)/`!#K$0`@``VR3P`1U0?S*!`HIX0`
M!<#E___H;NMO\V``!`?^!P?K[_!P`"2G*0"`X_#_8/]QP.7__^7NP#%G12,!
MXS`@```DP#_OS:N)XS`@"``DP#^8NMS^XS`@$``DP#$0,E1VY4@@*```XS`@
M&``DY4@@,```P#_#TN'PY4P@>```XS`@(``DZ^_Q$``$!_X'!P<'ZV_P,``D
MZQ0``P`-N00`DKD$`*/C("`H``2Y"``2[#$@OP!5X_#_8/]QN00`M+DQ`"&G
MQ``%ZP&0,`!ZXS"0*``DZQL`'0`,XQ"0,``(XQ"0,``D07"0..,0D'@`$J>$
M`"^GB`!`&X$9B[D$`">Y\C"+N1@`(;D4`&CL*@!&H&6YZ&`2N6%`H;D$`$:Y
M!``ZP.7__^?&&!A:$)!X4!"0>.P6`"]`?KGY@(NY"`"FN10`N+D$`"G`Y?__
M],7KBP`&`-ZGB@`!$KNG&``!N?)0@4%@D'BGA@`BN2$`IZ?$`#ZYZ+`7N6%`
MH;D$`$NY!``ZN00`)\#E___GE%"PD'CK;_#0``0'_KGH8!KL*O^_P&6Y84`A
MI_3_NKDA`*=!$*!`I\0`!^RF``J@9:?T``&GI``%[''__$!ETC]P`*``I[K_
MP+D$`*&Y%`"[N00`*<#E___T>:?T_\"GI/_(N>BP&KEA0'&G]/_"ZX_P0``D
MN00`HN.0,"@`!..`,#``!.PI.K\]5>P2``$`V+D4`")!(C`XDH`@`./P_V#_
M<;D4`"&Y!`"S04(P..P<`%DX?J<H`$"G60``N?D0$KD$`"2Y%@`QITD``*@D
M``"G%/_^N00`*\#E___T-]<WL#BP.$*`L'-"D+!WZQ@`&``,0A"P<.L8`!``
M#$(0L''K&``(``Q"$+!RZQD`&``,0A"P=.L9`!``#$(0L'7K&0`(``Q"$+!V
MN00`*\#E___T#=(#H`"P!+D$`"O2`Z`$L`S2`Z`(L!32`Z`,L!S2`Z`0L"3K
MC_#@``3`]/__YI2G*``XIUD``+GY$!*Y!``DN18`,:=)``"H)```IQ3__J?T
M_[('!^OO\'``)+D$``^G^_]@XP#P```DZ^_Q$``$!_XN`"XN```E<R\E<P!$
M>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/
M3U0``&5X90`O<')O8R\E:2\E<P!005)?5$5-4```4$%27U!23T=.04U%```Z
M`"\`4$523#5,24(``%!%4DQ,24(`4$523#5/4%0``%!%4DQ)3P``4$%27TE.
M251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%2
M7T-!0TA%`%!!4E]'3$]"04Q?1$5"54<``%!!4E]'3$]"04Q?5$U01$E2`%!!
M4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.```Q
M`$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@``'!A<BT``"5S)7,E<R5S
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P
M97)A=&EO;BD*``!0051(``!P87)L```N<&%R```E<R5S8V%C:&4M)7,E<P``
M)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S```8`'!E<FP``#``4$%2
M.CI086-K97(Z.E9%4E-)3TX``#$N,#4V`%5N86)L92!T;R!C<F5A=&4@8V%C
M:&4@9&ER96-T;W)Y```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```M90``+2T``%53
M15(``%5315).04U%``!414U01$E2`%1-4``O=&UP``!E=F%L("=E>&5C("]U
M<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N
M;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D
M4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@)$-!0TA%7VUA<FME<BP@
M)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!
M4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I
M"B1C86-H95]M87)K97(@/2`B7#!#04-(12(["B1C86-H95]N86UE7W-I>F4@
M/2`T,#L*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM
M>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@
M/2`M<R`D9F@["FUY("1P;W,@/2`D<VEZ92`M("1S:7IE("4@)&-H=6YK7W-I
M>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK
M7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*
M<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'
M24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^
M/2`P*2!["B1P;W,@*ST@)&D["G)E='5R;B`D<&]S.PI]"B1P;W,@+3T@)&-H
M=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G
M;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6
M>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I
M;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@
M/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q
M6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z
M.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D
M<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@
M)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E
M;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E
M;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,
M24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP
M<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[
M(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G
M(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O
M;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L
M("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R
M/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O
M=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*
M?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN
M960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N
M=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@
M*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG
M*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W
M:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I
M.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A
M<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%2
M7U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*34%'24,Z
M('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E
M;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E
M860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H
M97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@
M)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC
M7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B
M)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#
M.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?
M<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I
M>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@
M)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O
M;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G
M:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD9&%T
M85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L
M("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H
M92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)
M3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^
M('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E
M;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI
M.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH
M/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN
M86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2`I('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1B87-E;F%M921E>'0B
M+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*
M96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U
M9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER
M95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL
M;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*
M<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]
M("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*
M9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@
M/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.
M?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@
M9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^
M>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92![
M"FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D
M:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N
M(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R
M96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T
M<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B
M.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE
M879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E
M($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E
M<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O
M<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O
M7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D
M9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN
M<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*
M=6YL97-S("@D8G5F(&5Q(")02UPP,#-<,#`T(BD@>PIO=71S*'%Q6TYO('II
M<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE
M(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A
M<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D[
M"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A21553
M12!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@
M;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*
M;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L
M;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I
M9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G
M*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@
M0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A
M9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!
M24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@
M>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2![
M"F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T
M($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@
M)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]
M"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF
M("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG
M*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E
M;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD
M8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@
M/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII
M;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?
M*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?
M:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D
M<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG
M="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ
M1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@
M(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M
M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A
M(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE
M=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D
M("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q
M6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E
M860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F
M:6QE72!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["F-L;W-E("1P:#L*
M?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*
M)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,
M62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;
M0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I
M.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)&1A
M=&%?<&]S*2!["G)E860@7T9(+"`D;&]A9&5R+"`D9&%T85]P;W,["GT@96QS
M92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`
M<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0II9B`H
M)&UE=&%?<&%R>V-L96%N?2D@>PIM>2`D<&%R7V-L96%N(#T@(CTQ(CL*;7D@
M)'!A<W-?<&%R7V-L96%N(#T@=6,@(E]?<&%S<U]P87)?8VQE86Y?7R(["B1L
M;V%D97(@/7X@<WLH/SP])'MP87-S7W!A<E]C;&5A;GTI*"`K*7T*>R1P87)?
M8VQE86X@+B`H(B`B('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'!A<E]C;&5A
M;BDI*7UE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I
M('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`
M:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G
M<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@
M86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.
M0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*
M)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C
M=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I
M9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*
M;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE
M<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M
M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`
M:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F
M:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^
M(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO
M9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D[
M"FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]
M("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D
M969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT
M(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D
M+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E
M9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N
M=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT[
M"GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR
M87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T[
M"B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*
M:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\
M:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P
M<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&
M24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B
M)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT
M*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT
M96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O
M("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]
M"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG
M('II<"!P87)T(&]F("(D;W5T(ET["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@
M)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["FEF("@A)&-A8VAE
M7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D
M8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D=&@L("(\.G)A
M=R(L("1O=70["B1C='@M/F%D9&9I;&4H)'1H*3L*8VQO<V4@)'1H.PHD8V%C
M:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B
M7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I
M.PHD8V%C:&5?;F%M92`N/2`D8V%C:&5?;6%R:V5R.PIM>2`D;V9F<V5T(#T@
M)&9H+3YT96QL("L@;&5N9W1H*"1C86-H95]N86UE*2`M(&QE;F=T:"@D;&]A
M9&5R*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*<&%C:R@G3B<L("1O9F9S
M970I+`HD4$%27TU!1TE#*0HF)B`D9F@M/F-L;W-E"F]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L
M("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P
M;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O
M<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?
M1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C
M:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I
M92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*
M07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`
M4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE
M?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES
M('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@
M>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA
M;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N
M86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I
M;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK
M*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@
M/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C
M=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R
M+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE
M;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?
M;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R
M7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C
M=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T
M;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D
M7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z
M("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R
M8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL
M95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]
M("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N
M86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N
M86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E
M*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ
M4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T
M:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q
M=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R
M.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V
M87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X
M<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#
M;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*
M<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!]
M.PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L
M87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U
M<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E
M('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C
M86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R
M7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX[
M"GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?
M5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%
M35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD
M("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U
M:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@
M)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S
M97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@
M)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N
M86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-
M)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?
M9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B
M.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F
M:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S
M971?<VEZ90HM(&QE;F=T:"@D8V%C:&5?;6%R:V5R*2P@,#L*;7D@)&)U9CL*
M<F5A9"`D9F@L("1B=68L(&QE;F=T:"@D8V%C:&5?;6%R:V5R*3L*:68@*"1B
M=68@97$@)&-A8VAE7VUA<FME<BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM
M("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*"1C86-H95]M87)K97(I"BT@
M)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N
M86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H
M92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*
M)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*
M?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER
M("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL
M87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@
M*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@
M/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*
M;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@
M)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E
M;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B
M)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E
M9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@
M=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@
M7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%
M?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA
M;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-
M4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I
M('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G
M;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P
M*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N
M(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2![
M"B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H
M(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!
M5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER
M(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<
M120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M
M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD
M<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E
M;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@
M)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N
M)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@
M)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I
M;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M
M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI
M;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD
M14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@
M)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@
M1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?
M)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D
M14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*
M<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R
M:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]
M"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R
M97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H
M;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD
M;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q
M=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M
M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N
M('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER
M96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*
M0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*
M0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH
M*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?
M7T5.1%]?"@``<&5R;'AS:2YC``$;`SL```#0````&?__C30```3L__^0O```
M`.S__Y%L```!*/__D;0```%4__^2/````83__Y+,```!M/__E"0```'L__^6
M5````BC__Y:,```"//__EO0```)X__^7]````K3__Y?\```"R/__F@0```,$
M__^:/````S#__YML```#</__G)P```.4__^=#````\#__YT\```#X/__G>P`
M``0L__^D+```!'S__Z9L```$L/__IM0```4L__^\)```!6C__[R4```%C/__
MO?P```7(````%``````!>E(``7@.`1L,#Z`!````````.````!S__X_(````
MK@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#L`"`H(*S\[-S,O*R<C'Q@Z@`4(+
M````*````%C__Y`\````0@!&BPF,"(T'C@:/!48.T`)TS\[-S,L.H`$`````
M```L````A/__D%@```"&`$:)"XH*BPF,"(T'C@:/!48.T`(">,_.S<S+RLD.
MH`$````L````M/__D+````"0`$:*"HL)C`B-!XX&CP5&#M@#`H+/SLW,R\H.
MH`$````````T````Y/__D1````%4`$:'#8@,B0N*"HL)C`B-!XX&CP5&#M@#
M`P%&S\[-S,O*R<C'#J`!`````#@```$<__^2,````BP`1H8.APV(#(D+B@J+
M"8P(C0>.!H\%1@[0`@,"'L_.S<S+RLG(Q\8.H`$``````!````%8__^4)```
M`#@`````````.````6S__Y1(````8@!,A@Z'#8@,B0N*"HL)C`B-!XX&CP5&
M#L@"`D[/SLW,R\K)R,?&#J`!````````.````:C__Y1T````_@!&A@Z'#8@,
MB0N*"HL)C`B-!XX&CP5&#M!"`O#/SLW,R\K)R,?&#J`!````````$````>3_
M_Y4X````!@`````````X```!^/__E2P```("`$:&#H<-B`R)"XH*BPF,"(T'
MC@:/!48.X",#`?3/SLW,R\K)R,?&#J`!```````H```"-/__EO@````T`$J+
M"8P(C0>.!H\%1@[``E[/SLW,RPZ@`0```````#P```)@__^7!````2H`1HH*
MBPF,"(T'C@:/!48.R"("[`K/SLW,R\H.H`%""V(*S\[-S,O*#J`!1@L`````
M```@```"H/__E_0```$N`$R.!H\%1@[``@+V"L_.#J`!1@L````H```"Q/__
MF0````!L`%J.!H\%1@[``GH*S\X.H`%""T@.H`'.SP```````!P```+P__^9
M1````"P`1HX&CP5&#L`"7L_.#J`!````2````Q#__YE4````K`!&A@Z'#8@,
MB0N*"HL)C`B-!XX&CP5*#L`";@K/SLW,R\K)R,?&#J`!1@L"9L_.S<S+RLG(
MQ\8.H`$``````$P```-<__^9N```!D``1H8.APV(#(D+B@J+"8P(C0>.!H\%
M1@Z(A0("A@K/SLW,R\K)R,?&#J`!1@L#`;X*S\[-S,O*R<C'Q@Z@`4(+````
M,````ZS__Y^H```"/`!,B`R)"XH*BPF,"(T'C@:/!6`.P`(#`@[/SLW,R\K)
MR`Z@`0```#@```/@__^AM````&@`1HH*BPF,"(T'C@:/!48.P`("3@K/SLW,
MR\H.H`%&"T;/SLW,R\H.H`$``````#P```0<__^(0````?H`1H8.APV(#(D+
MB@J+"8P(C0>.!H\%1@[8`@,!U@K/SLW,R\K)R,?&#J`!0@L````````X```$
M7/__H:```!5.`%B&#H<-B`R)"XH*BPF,"(T'C@:/!48.T`<#%2[/SLW,R\K)
MR,?&#J`!```````@```$F/__MK0```!L`$J.!H\%1@[``@):S\X.H`$`````
M```X```$O/__MP````%H`$R&#H<-B`R)"XH*BPF,"(T'C@:/!5X.P`("V@K/
MSLW,R\K)R,?&#J`!0@L````T```$^/__N"P```$6`$:(#(D+B@J+"8P(C0>.
M!H\%;@[``@*X"L_.S<S+RLG(#J`!1@L`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````B2````````"'@``````````$````````"S0`````````!````
M`````M@`````````#P````````0"``````````P````````7P``````````-
M````````4.``````````&0```````*O``````````!L`````````"```````
M```:````````J\@`````````'``````````(`````&___O4````````"&```
M```````%````````"\``````````!@````````+P``````````H````````$
M(``````````+`````````!@`````````%0````````````````````,`````
M``"ML``````````"````````!4``````````%``````````'`````````!<`
M```````2@``````````'````````#^``````````"`````````*@````````
M``D`````````&``````````8````````````````;___^P`````(```!````
M`&____D`````````$```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````J]``````````````````````````````&`H````````8*@``
M`````!A*````````&&H````````8B@```````!BJ````````&,H````````8
MZ@```````!D*````````&2H````````92@```````!EJ````````&8H`````
M```9J@```````!G*````````&>H````````:"@```````!HJ````````&DH`
M```````::@```````!J*````````&JH````````:R@```````!KJ````````
M&PH````````;*@```````!M*````````&VH````````;B@```````!NJ````
M````&\H````````;Z@```````!P*````````'"H````````<2@```````!QJ
M````````'(H````````<J@```````!S*````````'.H````````="@``````
M`!TJ````````'4H````````=:@```````!V*````````':H````````=R@``
M`````!WJ````````'@H````````>*@```````!Y*````````'FH````````>
MB@```````!ZJ````````'LH````````>Z@```````!\`````````````````
M`````````````%#@`````````````````````````````!?`````````````
M````````````````````````````````````````````````````````````
M`````````````````````+``_____P````````````!3Q@```````%#\````
M``````````````!1Z````````%'L````````4[H```````!13@```````%/"
M``````````````````!3J@```````%.P``````````````````!3S$=#0SH@
M*$%L<&EN92`Q,BXR+C%?9VET,C`R,C`Y,C0M<C0I(#$R+C(N,2`R,#(R,#DR
M-```+G-H<W1R=&%B`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T
M<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A
M=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?
M87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT````````
M````````````````````````````````````````````````````````````
M````````````````````````````````"P````$``````````@````````(`
M`````````@``````````&`````````````````````$``````````````!-O
M___V``````````(````````"&`````````(8`````````-@````#````````
M```````(```````````````=````"P`````````"`````````O`````````"
M\`````````C0````!`````(`````````"``````````8````)0````,`````
M`````@````````O`````````"\`````````$(`````````````````````$`
M`````````````"T````$``````````(````````/X`````````_@````````
M`J`````#```````````````(`````````!@````W````!`````````!"````
M````$H`````````2@`````````5``````P```!$`````````"``````````8
M````00````$`````````!@```````!?`````````%\``````````'```````
M``````````````(``````````````#P````!``````````8````````7W```
M`````!?<````````!R`````````````````````$`````````"````!'````
M`0`````````&````````'P`````````?`````````#'@````````````````
M````"```````````````30````$`````````!@```````%#@````````4.``
M````````'`````````````````````(``````````````%,````!````````
M``(```````!0_````````%#\````````0-`````````````````````"````
M``````````!;`````0`````````"````````D<P```````"1S`````````#4
M````````````````````!```````````````:0````$``````````@``````
M`)*@````````DJ`````````%,`````````````````````@`````````````
M`',````.``````````,```````"KP````````)O```````````@`````````
M```````````(``````````@```!_````#P`````````#````````J\@`````
M``";R``````````(````````````````````"``````````(````BP````8`
M`````````P```````*O0````````F]`````````!X`````0`````````````
M``@`````````$````)0````!``````````,```````"ML````````)VP````
M`````E`````````````````````(``````````@```"9`````0`````````#
M````````L`````````"@``````````!X````````````````````"```````
M````````GP````@``````````P```````+!X````````H'@`````````6```
M``````````````````@``````````````*0````!`````````#``````````
M`````````*!X`````````#0````````````````````!``````````$````!
M`````P````````````````````````````"@K`````````"M````````````
/`````````0``````````
